# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rockset/query_field_path.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rockset/query_field_path.proto',
  package='rockset',
  syntax='proto3',
  serialized_options=b'\n\020io.rockset.protoP\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1erockset/query_field_path.proto\x12\x07rockset\"\x1a\n\x18\x41llIndexesQueryFieldPath\"\xb1\x01\n\x17QueryFieldPathComponent\x12\x0f\n\x05index\x18\x01 \x01(\x05H\x00\x12\r\n\x03key\x18\x02 \x01(\tH\x00\x12\x38\n\x0b\x61ll_indexes\x18\x03 \x01(\x0b\x32!.rockset.AllIndexesQueryFieldPathH\x00\x12.\n\rspecial_field\x18\x04 \x01(\x0e\x32\x15.rockset.SpecialFieldH\x00\x42\x0c\n\npath_union\"F\n\x0eQueryFieldPath\x12\x34\n\ncomponents\x18\x01 \x03(\x0b\x32 .rockset.QueryFieldPathComponent* \n\x0cSpecialField\x12\x10\n\x0cSFIELD_SCORE\x10\x00\x42\x14\n\x10io.rockset.protoP\x00\x62\x06proto3'
)

_SPECIALFIELD = _descriptor.EnumDescriptor(
  name='SpecialField',
  full_name='rockset.SpecialField',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SFIELD_SCORE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=323,
  serialized_end=355,
)
_sym_db.RegisterEnumDescriptor(_SPECIALFIELD)

SpecialField = enum_type_wrapper.EnumTypeWrapper(_SPECIALFIELD)
SFIELD_SCORE = 0



_ALLINDEXESQUERYFIELDPATH = _descriptor.Descriptor(
  name='AllIndexesQueryFieldPath',
  full_name='rockset.AllIndexesQueryFieldPath',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=43,
  serialized_end=69,
)


_QUERYFIELDPATHCOMPONENT = _descriptor.Descriptor(
  name='QueryFieldPathComponent',
  full_name='rockset.QueryFieldPathComponent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='rockset.QueryFieldPathComponent.index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='rockset.QueryFieldPathComponent.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='all_indexes', full_name='rockset.QueryFieldPathComponent.all_indexes', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='special_field', full_name='rockset.QueryFieldPathComponent.special_field', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='path_union', full_name='rockset.QueryFieldPathComponent.path_union',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=72,
  serialized_end=249,
)


_QUERYFIELDPATH = _descriptor.Descriptor(
  name='QueryFieldPath',
  full_name='rockset.QueryFieldPath',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='components', full_name='rockset.QueryFieldPath.components', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=321,
)

_QUERYFIELDPATHCOMPONENT.fields_by_name['all_indexes'].message_type = _ALLINDEXESQUERYFIELDPATH
_QUERYFIELDPATHCOMPONENT.fields_by_name['special_field'].enum_type = _SPECIALFIELD
_QUERYFIELDPATHCOMPONENT.oneofs_by_name['path_union'].fields.append(
  _QUERYFIELDPATHCOMPONENT.fields_by_name['index'])
_QUERYFIELDPATHCOMPONENT.fields_by_name['index'].containing_oneof = _QUERYFIELDPATHCOMPONENT.oneofs_by_name['path_union']
_QUERYFIELDPATHCOMPONENT.oneofs_by_name['path_union'].fields.append(
  _QUERYFIELDPATHCOMPONENT.fields_by_name['key'])
_QUERYFIELDPATHCOMPONENT.fields_by_name['key'].containing_oneof = _QUERYFIELDPATHCOMPONENT.oneofs_by_name['path_union']
_QUERYFIELDPATHCOMPONENT.oneofs_by_name['path_union'].fields.append(
  _QUERYFIELDPATHCOMPONENT.fields_by_name['all_indexes'])
_QUERYFIELDPATHCOMPONENT.fields_by_name['all_indexes'].containing_oneof = _QUERYFIELDPATHCOMPONENT.oneofs_by_name['path_union']
_QUERYFIELDPATHCOMPONENT.oneofs_by_name['path_union'].fields.append(
  _QUERYFIELDPATHCOMPONENT.fields_by_name['special_field'])
_QUERYFIELDPATHCOMPONENT.fields_by_name['special_field'].containing_oneof = _QUERYFIELDPATHCOMPONENT.oneofs_by_name['path_union']
_QUERYFIELDPATH.fields_by_name['components'].message_type = _QUERYFIELDPATHCOMPONENT
DESCRIPTOR.message_types_by_name['AllIndexesQueryFieldPath'] = _ALLINDEXESQUERYFIELDPATH
DESCRIPTOR.message_types_by_name['QueryFieldPathComponent'] = _QUERYFIELDPATHCOMPONENT
DESCRIPTOR.message_types_by_name['QueryFieldPath'] = _QUERYFIELDPATH
DESCRIPTOR.enum_types_by_name['SpecialField'] = _SPECIALFIELD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AllIndexesQueryFieldPath = _reflection.GeneratedProtocolMessageType('AllIndexesQueryFieldPath', (_message.Message,), {
  'DESCRIPTOR' : _ALLINDEXESQUERYFIELDPATH,
  '__module__' : 'rockset.query_field_path_pb2'
  # @@protoc_insertion_point(class_scope:rockset.AllIndexesQueryFieldPath)
  })
_sym_db.RegisterMessage(AllIndexesQueryFieldPath)

QueryFieldPathComponent = _reflection.GeneratedProtocolMessageType('QueryFieldPathComponent', (_message.Message,), {
  'DESCRIPTOR' : _QUERYFIELDPATHCOMPONENT,
  '__module__' : 'rockset.query_field_path_pb2'
  # @@protoc_insertion_point(class_scope:rockset.QueryFieldPathComponent)
  })
_sym_db.RegisterMessage(QueryFieldPathComponent)

QueryFieldPath = _reflection.GeneratedProtocolMessageType('QueryFieldPath', (_message.Message,), {
  'DESCRIPTOR' : _QUERYFIELDPATH,
  '__module__' : 'rockset.query_field_path_pb2'
  # @@protoc_insertion_point(class_scope:rockset.QueryFieldPath)
  })
_sym_db.RegisterMessage(QueryFieldPath)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
