# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rockset/regex.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rockset/regex.proto',
  package='rockset',
  syntax='proto3',
  serialized_options=b'\n\020io.rockset.protoP\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13rockset/regex.proto\x12\x07rockset\"e\n\x05Regex\x12\x0f\n\x07pattern\x18\x01 \x01(\t\x12)\n\x08\x65ncoding\x18\x02 \x01(\x0e\x32\x17.rockset.Regex.Encoding\" \n\x08\x45ncoding\x12\x08\n\x04UTF8\x10\x00\x12\n\n\x06LATIN1\x10\x01\x42\x14\n\x10io.rockset.protoP\x00\x62\x06proto3'
)



_REGEX_ENCODING = _descriptor.EnumDescriptor(
  name='Encoding',
  full_name='rockset.Regex.Encoding',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UTF8', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LATIN1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=101,
  serialized_end=133,
)
_sym_db.RegisterEnumDescriptor(_REGEX_ENCODING)


_REGEX = _descriptor.Descriptor(
  name='Regex',
  full_name='rockset.Regex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pattern', full_name='rockset.Regex.pattern', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encoding', full_name='rockset.Regex.encoding', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _REGEX_ENCODING,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32,
  serialized_end=133,
)

_REGEX.fields_by_name['encoding'].enum_type = _REGEX_ENCODING
_REGEX_ENCODING.containing_type = _REGEX
DESCRIPTOR.message_types_by_name['Regex'] = _REGEX
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Regex = _reflection.GeneratedProtocolMessageType('Regex', (_message.Message,), {
  'DESCRIPTOR' : _REGEX,
  '__module__' : 'rockset.regex_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Regex)
  })
_sym_db.RegisterMessage(Regex)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
