# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rockset/value.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rockset import document_locator_pb2 as rockset_dot_document__locator__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rockset/value.proto',
  package='rockset',
  syntax='proto3',
  serialized_options=b'\n\020io.rockset.protoP\000\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13rockset/value.proto\x12\x07rockset\x1a\x1erockset/document_locator.proto\"\x07\n\x05\x45mpty\"5\n\tDateProto\x12\x0c\n\x04year\x18\x01 \x01(\x03\x12\r\n\x05month\x18\x02 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\x05\"N\n\tTimeProto\x12\x0c\n\x04hour\x18\x01 \x01(\x05\x12\x0e\n\x06minute\x18\x02 \x01(\x05\x12\x0e\n\x06second\x18\x03 \x01(\x05\x12\x13\n\x0bmicrosecond\x18\x04 \x01(\x05\"S\n\rDateTimeProto\x12 \n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x12.rockset.DateProto\x12 \n\x04time\x18\x02 \x01(\x0b\x32\x12.rockset.TimeProto\":\n\x13GeographyPointProto\x12\x11\n\tlongitude\x18\x01 \x01(\x01\x12\x10\n\x08latitude\x18\x02 \x01(\x01\"H\n\x18GeographyLineStringProto\x12,\n\x06points\x18\x01 \x03(\x0b\x32\x1c.rockset.GeographyPointProto\"I\n\x15GeographyPolygonProto\x12\x30\n\x05loops\x18\x01 \x03(\x0b\x32!.rockset.GeographyLineStringProto\"1\n\x1bGeographyRangeEndpointProto\x12\x12\n\nindex_term\x18\x01 \x01(\t\"\xff\x01\n\x0eGeographyProto\x12-\n\x05point\x18\x01 \x01(\x0b\x32\x1c.rockset.GeographyPointProtoH\x00\x12\x38\n\x0bline_string\x18\x02 \x01(\x0b\x32!.rockset.GeographyLineStringProtoH\x00\x12\x31\n\x07polygon\x18\x03 \x01(\x0b\x32\x1e.rockset.GeographyPolygonProtoH\x00\x12>\n\x0erange_endpoint\x18\x04 \x01(\x0b\x32$.rockset.GeographyRangeEndpointProtoH\x00\x42\x11\n\x0fgeography_union\"%\n\x0bInt128Proto\x12\n\n\x02hi\x18\x01 \x01(\x04\x12\n\n\x02lo\x18\x02 \x01(\x04\"\x86\x0b\n\x05Value\x12\x13\n\tint_value\x18\x01 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x02 \x01(\x01H\x00\x12\x14\n\nbool_value\x18\x03 \x01(\x08H\x00\x12\x16\n\x0cstring_value\x18\x04 \x01(\tH\x00\x12\x15\n\x0b\x62ytes_value\x18\x05 \x01(\x0cH\x00\x12,\n\x0cobject_value\x18\x06 \x01(\x0b\x32\x14.rockset.ObjectValueH\x00\x12*\n\x0b\x61rray_value\x18\x07 \x01(\x0b\x32\x13.rockset.ArrayValueH\x00\x12,\n\x0c\x63ustom_value\x18\x08 \x01(\x0b\x32\x14.rockset.CustomValueH\x00\x12\x14\n\nnull_value\x18\t \x01(\x08H\x00\x12.\n\rlocator_value\x18\n \x01(\x0b\x32\x15.DocumentLocatorProtoH\x00\x12\x19\n\x0ftimestamp_value\x18\x0b \x01(\x03H\x00\x12\x30\n\x0e\x64\x61tetime_value\x18\x0c \x01(\x0b\x32\x16.rockset.DateTimeProtoH\x00\x12(\n\ndate_value\x18\r \x01(\x0b\x32\x12.rockset.DateProtoH\x00\x12(\n\ntime_value\x18\x0e \x01(\x0b\x32\x12.rockset.TimeProtoH\x00\x12\x1e\n\x14month_interval_value\x18\x0f \x01(\x03H\x00\x12$\n\x1amicrosecond_interval_value\x18\x10 \x01(\x03H\x00\x12\x17\n\runknown_value\x18\x11 \x01(\x08H\x00\x12\x32\n\x0fgeography_value\x18\x12 \x01(\x0b\x32\x17.rockset.GeographyProtoH\x00\x12\x31\n\x0fint_array_value\x18\x13 \x01(\x0b\x32\x16.rockset.IntArrayValueH\x00\x12\x35\n\x11\x66loat_array_value\x18\x14 \x01(\x0b\x32\x18.rockset.FloatArrayValueH\x00\x12\x33\n\x10\x62ool_array_value\x18\x15 \x01(\x0b\x32\x17.rockset.BoolArrayValueH\x00\x12\x37\n\x12string_array_value\x18\x16 \x01(\x0b\x32\x19.rockset.StringArrayValueH\x00\x12\x39\n\x13locator_array_value\x18\x17 \x01(\x0b\x32\x1a.rockset.LocatorArrayValueH\x00\x12=\n\x15timestamp_array_value\x18\x18 \x01(\x0b\x32\x1c.rockset.TimestampArrayValueH\x00\x12<\n\x15\x64\x61te_time_array_value\x18\x19 \x01(\x0b\x32\x1b.rockset.DateTimeArrayValueH\x00\x12\x33\n\x10\x64\x61te_array_value\x18\x1a \x01(\x0b\x32\x17.rockset.DateArrayValueH\x00\x12\x33\n\x10time_array_value\x18\x1b \x01(\x0b\x32\x17.rockset.TimeArrayValueH\x00\x12\x46\n\x1amonth_interval_array_value\x18\x1c \x01(\x0b\x32 .rockset.MonthIntervalArrayValueH\x00\x12R\n microsecond_interval_array_value\x18\x1d \x01(\x0b\x32&.rockset.MicrosecondIntervalArrayValueH\x00\x12,\n\x0cint128_value\x18\x1e \x01(\x0b\x32\x14.rockset.Int128ProtoH\x00\x12\x37\n\x12int128_array_value\x18\x1f \x01(\x0b\x32\x19.rockset.Int128ArrayValueH\x00\x42\r\n\x0bvalue_union\",\n\x0b\x43ustomValue\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\x0f\n\x07\x65ncoded\x18\x02 \x01(\x0c\"3\n\x05\x46ield\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.rockset.Value\"-\n\x0bObjectValue\x12\x1e\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x0e.rockset.Field\"+\n\nArrayValue\x12\x1d\n\x05value\x18\x02 \x03(\x0b\x32\x0e.rockset.Value\"\x1d\n\nNullsValue\x12\x0f\n\x07storage\x18\x01 \x03(\x04\"B\n\rIntArrayValue\x12\r\n\x05value\x18\x01 \x03(\x03\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"D\n\x0f\x46loatArrayValue\x12\r\n\x05value\x18\x01 \x03(\x01\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"C\n\x0e\x42oolArrayValue\x12\r\n\x05value\x18\x01 \x03(\x08\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"<\n\x1aStringArrayValueDictionary\x12\x0f\n\x07offsets\x18\x01 \x03(\r\x12\r\n\x05words\x18\x02 \x01(\x0c\"~\n\x10StringArrayValue\x12\r\n\x05value\x18\x01 \x03(\r\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\x12\x37\n\ndictionary\x18\x03 \x01(\x0b\x32#.rockset.StringArrayValueDictionary\"]\n\x11LocatorArrayValue\x12$\n\x05value\x18\x01 \x03(\x0b\x32\x15.DocumentLocatorProto\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"H\n\x13TimestampArrayValue\x12\r\n\x05value\x18\x01 \x03(\x03\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"_\n\x12\x44\x61teTimeArrayValue\x12%\n\x05value\x18\x01 \x03(\x0b\x32\x16.rockset.DateTimeProto\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"W\n\x0e\x44\x61teArrayValue\x12!\n\x05value\x18\x01 \x03(\x0b\x32\x12.rockset.DateProto\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"W\n\x0eTimeArrayValue\x12!\n\x05value\x18\x01 \x03(\x0b\x32\x12.rockset.TimeProto\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"L\n\x17MonthIntervalArrayValue\x12\r\n\x05value\x18\x01 \x03(\x03\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"R\n\x1dMicrosecondIntervalArrayValue\x12\r\n\x05value\x18\x01 \x03(\x03\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"[\n\x10Int128ArrayValue\x12#\n\x05value\x18\x01 \x03(\x0b\x32\x14.rockset.Int128Proto\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"\x8c\x03\n\x04Type\x12(\n\x04type\x18\x01 \x01(\x0e\x32\x18.rockset.Type.ScalarTypeH\x00\x12*\n\x0bobject_type\x18\x02 \x01(\x0b\x32\x13.rockset.ObjectTypeH\x00\x12(\n\narray_type\x18\x03 \x01(\x0b\x32\x12.rockset.ArrayTypeH\x00\x12*\n\x0b\x63ustom_type\x18\x04 \x01(\x0b\x32\x13.rockset.CustomTypeH\x00\x12\x10\n\x08inferred\x18\x05 \x01(\x08\x12%\n\rdefault_value\x18\x06 \x01(\x0b\x32\x0e.rockset.Value\x12#\n\x0csource_field\x18\x07 \x01(\x0b\x32\r.rockset.Type\x12\x0e\n\x06stored\x18\x08 \x01(\x08\x12\x0f\n\x07indexed\x18\t \x01(\x08\"K\n\nScalarType\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03INT\x10\x01\x12\t\n\x05\x46LOAT\x10\x02\x12\x08\n\x04\x42OOL\x10\x03\x12\n\n\x06STRING\x10\x04\x12\t\n\x05\x42YTES\x10\x05\x42\x0c\n\ntype_union\"3\n\x07KeyType\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1b\n\x04type\x18\x02 \x01(\x0b\x32\r.rockset.Type\"*\n\nObjectType\x12\x1c\n\x02kt\x18\x01 \x03(\x0b\x32\x10.rockset.KeyType\"(\n\tArrayType\x12\x1b\n\x04type\x18\x01 \x01(\x0b\x32\r.rockset.Type\"\x1a\n\nCustomType\x12\x0c\n\x04type\x18\x01 \x01(\r\"\x1d\n\x0b\x42itSetProto\x12\x0e\n\x06\x62locks\x18\x01 \x03(\x07\x42\x17\n\x10io.rockset.protoP\x00\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[rockset_dot_document__locator__pb2.DESCRIPTOR,])



_TYPE_SCALARTYPE = _descriptor.EnumDescriptor(
  name='ScalarType',
  full_name='rockset.Type.ScalarType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLOAT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOOL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BYTES', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3893,
  serialized_end=3968,
)
_sym_db.RegisterEnumDescriptor(_TYPE_SCALARTYPE)


_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='rockset.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=71,
)


_DATEPROTO = _descriptor.Descriptor(
  name='DateProto',
  full_name='rockset.DateProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='year', full_name='rockset.DateProto.year', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month', full_name='rockset.DateProto.month', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='day', full_name='rockset.DateProto.day', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=126,
)


_TIMEPROTO = _descriptor.Descriptor(
  name='TimeProto',
  full_name='rockset.TimeProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hour', full_name='rockset.TimeProto.hour', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minute', full_name='rockset.TimeProto.minute', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='second', full_name='rockset.TimeProto.second', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='microsecond', full_name='rockset.TimeProto.microsecond', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=128,
  serialized_end=206,
)


_DATETIMEPROTO = _descriptor.Descriptor(
  name='DateTimeProto',
  full_name='rockset.DateTimeProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='rockset.DateTimeProto.date', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='rockset.DateTimeProto.time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=208,
  serialized_end=291,
)


_GEOGRAPHYPOINTPROTO = _descriptor.Descriptor(
  name='GeographyPointProto',
  full_name='rockset.GeographyPointProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='longitude', full_name='rockset.GeographyPointProto.longitude', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latitude', full_name='rockset.GeographyPointProto.latitude', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=293,
  serialized_end=351,
)


_GEOGRAPHYLINESTRINGPROTO = _descriptor.Descriptor(
  name='GeographyLineStringProto',
  full_name='rockset.GeographyLineStringProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='points', full_name='rockset.GeographyLineStringProto.points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=353,
  serialized_end=425,
)


_GEOGRAPHYPOLYGONPROTO = _descriptor.Descriptor(
  name='GeographyPolygonProto',
  full_name='rockset.GeographyPolygonProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loops', full_name='rockset.GeographyPolygonProto.loops', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=427,
  serialized_end=500,
)


_GEOGRAPHYRANGEENDPOINTPROTO = _descriptor.Descriptor(
  name='GeographyRangeEndpointProto',
  full_name='rockset.GeographyRangeEndpointProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index_term', full_name='rockset.GeographyRangeEndpointProto.index_term', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=502,
  serialized_end=551,
)


_GEOGRAPHYPROTO = _descriptor.Descriptor(
  name='GeographyProto',
  full_name='rockset.GeographyProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='point', full_name='rockset.GeographyProto.point', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='line_string', full_name='rockset.GeographyProto.line_string', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon', full_name='rockset.GeographyProto.polygon', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='range_endpoint', full_name='rockset.GeographyProto.range_endpoint', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='geography_union', full_name='rockset.GeographyProto.geography_union',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=554,
  serialized_end=809,
)


_INT128PROTO = _descriptor.Descriptor(
  name='Int128Proto',
  full_name='rockset.Int128Proto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hi', full_name='rockset.Int128Proto.hi', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lo', full_name='rockset.Int128Proto.lo', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=811,
  serialized_end=848,
)


_VALUE = _descriptor.Descriptor(
  name='Value',
  full_name='rockset.Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='int_value', full_name='rockset.Value.int_value', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float_value', full_name='rockset.Value.float_value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bool_value', full_name='rockset.Value.bool_value', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='rockset.Value.string_value', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_value', full_name='rockset.Value.bytes_value', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_value', full_name='rockset.Value.object_value', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='array_value', full_name='rockset.Value.array_value', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_value', full_name='rockset.Value.custom_value', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='null_value', full_name='rockset.Value.null_value', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator_value', full_name='rockset.Value.locator_value', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_value', full_name='rockset.Value.timestamp_value', index=10,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datetime_value', full_name='rockset.Value.datetime_value', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date_value', full_name='rockset.Value.date_value', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_value', full_name='rockset.Value.time_value', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month_interval_value', full_name='rockset.Value.month_interval_value', index=14,
      number=15, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='microsecond_interval_value', full_name='rockset.Value.microsecond_interval_value', index=15,
      number=16, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unknown_value', full_name='rockset.Value.unknown_value', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geography_value', full_name='rockset.Value.geography_value', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int_array_value', full_name='rockset.Value.int_array_value', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float_array_value', full_name='rockset.Value.float_array_value', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bool_array_value', full_name='rockset.Value.bool_array_value', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_array_value', full_name='rockset.Value.string_array_value', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locator_array_value', full_name='rockset.Value.locator_array_value', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_array_value', full_name='rockset.Value.timestamp_array_value', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date_time_array_value', full_name='rockset.Value.date_time_array_value', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date_array_value', full_name='rockset.Value.date_array_value', index=25,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_array_value', full_name='rockset.Value.time_array_value', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month_interval_array_value', full_name='rockset.Value.month_interval_array_value', index=27,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='microsecond_interval_array_value', full_name='rockset.Value.microsecond_interval_array_value', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int128_value', full_name='rockset.Value.int128_value', index=29,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int128_array_value', full_name='rockset.Value.int128_array_value', index=30,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value_union', full_name='rockset.Value.value_union',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=851,
  serialized_end=2265,
)


_CUSTOMVALUE = _descriptor.Descriptor(
  name='CustomValue',
  full_name='rockset.CustomValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='rockset.CustomValue.type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encoded', full_name='rockset.CustomValue.encoded', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2267,
  serialized_end=2311,
)


_FIELD = _descriptor.Descriptor(
  name='Field',
  full_name='rockset.Field',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='rockset.Field.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.Field.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2313,
  serialized_end=2364,
)


_OBJECTVALUE = _descriptor.Descriptor(
  name='ObjectValue',
  full_name='rockset.ObjectValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='rockset.ObjectValue.fields', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2366,
  serialized_end=2411,
)


_ARRAYVALUE = _descriptor.Descriptor(
  name='ArrayValue',
  full_name='rockset.ArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.ArrayValue.value', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2413,
  serialized_end=2456,
)


_NULLSVALUE = _descriptor.Descriptor(
  name='NullsValue',
  full_name='rockset.NullsValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage', full_name='rockset.NullsValue.storage', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2458,
  serialized_end=2487,
)


_INTARRAYVALUE = _descriptor.Descriptor(
  name='IntArrayValue',
  full_name='rockset.IntArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.IntArrayValue.value', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nulls', full_name='rockset.IntArrayValue.nulls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2489,
  serialized_end=2555,
)


_FLOATARRAYVALUE = _descriptor.Descriptor(
  name='FloatArrayValue',
  full_name='rockset.FloatArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.FloatArrayValue.value', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nulls', full_name='rockset.FloatArrayValue.nulls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2557,
  serialized_end=2625,
)


_BOOLARRAYVALUE = _descriptor.Descriptor(
  name='BoolArrayValue',
  full_name='rockset.BoolArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.BoolArrayValue.value', index=0,
      number=1, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nulls', full_name='rockset.BoolArrayValue.nulls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2627,
  serialized_end=2694,
)


_STRINGARRAYVALUEDICTIONARY = _descriptor.Descriptor(
  name='StringArrayValueDictionary',
  full_name='rockset.StringArrayValueDictionary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offsets', full_name='rockset.StringArrayValueDictionary.offsets', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='words', full_name='rockset.StringArrayValueDictionary.words', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2696,
  serialized_end=2756,
)


_STRINGARRAYVALUE = _descriptor.Descriptor(
  name='StringArrayValue',
  full_name='rockset.StringArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.StringArrayValue.value', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nulls', full_name='rockset.StringArrayValue.nulls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dictionary', full_name='rockset.StringArrayValue.dictionary', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2758,
  serialized_end=2884,
)


_LOCATORARRAYVALUE = _descriptor.Descriptor(
  name='LocatorArrayValue',
  full_name='rockset.LocatorArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.LocatorArrayValue.value', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nulls', full_name='rockset.LocatorArrayValue.nulls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2886,
  serialized_end=2979,
)


_TIMESTAMPARRAYVALUE = _descriptor.Descriptor(
  name='TimestampArrayValue',
  full_name='rockset.TimestampArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.TimestampArrayValue.value', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nulls', full_name='rockset.TimestampArrayValue.nulls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2981,
  serialized_end=3053,
)


_DATETIMEARRAYVALUE = _descriptor.Descriptor(
  name='DateTimeArrayValue',
  full_name='rockset.DateTimeArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.DateTimeArrayValue.value', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nulls', full_name='rockset.DateTimeArrayValue.nulls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3055,
  serialized_end=3150,
)


_DATEARRAYVALUE = _descriptor.Descriptor(
  name='DateArrayValue',
  full_name='rockset.DateArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.DateArrayValue.value', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nulls', full_name='rockset.DateArrayValue.nulls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3152,
  serialized_end=3239,
)


_TIMEARRAYVALUE = _descriptor.Descriptor(
  name='TimeArrayValue',
  full_name='rockset.TimeArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.TimeArrayValue.value', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nulls', full_name='rockset.TimeArrayValue.nulls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3241,
  serialized_end=3328,
)


_MONTHINTERVALARRAYVALUE = _descriptor.Descriptor(
  name='MonthIntervalArrayValue',
  full_name='rockset.MonthIntervalArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.MonthIntervalArrayValue.value', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nulls', full_name='rockset.MonthIntervalArrayValue.nulls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3330,
  serialized_end=3406,
)


_MICROSECONDINTERVALARRAYVALUE = _descriptor.Descriptor(
  name='MicrosecondIntervalArrayValue',
  full_name='rockset.MicrosecondIntervalArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.MicrosecondIntervalArrayValue.value', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nulls', full_name='rockset.MicrosecondIntervalArrayValue.nulls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3408,
  serialized_end=3490,
)


_INT128ARRAYVALUE = _descriptor.Descriptor(
  name='Int128ArrayValue',
  full_name='rockset.Int128ArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rockset.Int128ArrayValue.value', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nulls', full_name='rockset.Int128ArrayValue.nulls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3492,
  serialized_end=3583,
)


_TYPE = _descriptor.Descriptor(
  name='Type',
  full_name='rockset.Type',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='rockset.Type.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_type', full_name='rockset.Type.object_type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='array_type', full_name='rockset.Type.array_type', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_type', full_name='rockset.Type.custom_type', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inferred', full_name='rockset.Type.inferred', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_value', full_name='rockset.Type.default_value', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_field', full_name='rockset.Type.source_field', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stored', full_name='rockset.Type.stored', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='indexed', full_name='rockset.Type.indexed', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TYPE_SCALARTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type_union', full_name='rockset.Type.type_union',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3586,
  serialized_end=3982,
)


_KEYTYPE = _descriptor.Descriptor(
  name='KeyType',
  full_name='rockset.KeyType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='rockset.KeyType.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='rockset.KeyType.type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3984,
  serialized_end=4035,
)


_OBJECTTYPE = _descriptor.Descriptor(
  name='ObjectType',
  full_name='rockset.ObjectType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kt', full_name='rockset.ObjectType.kt', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4037,
  serialized_end=4079,
)


_ARRAYTYPE = _descriptor.Descriptor(
  name='ArrayType',
  full_name='rockset.ArrayType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='rockset.ArrayType.type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4081,
  serialized_end=4121,
)


_CUSTOMTYPE = _descriptor.Descriptor(
  name='CustomType',
  full_name='rockset.CustomType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='rockset.CustomType.type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4123,
  serialized_end=4149,
)


_BITSETPROTO = _descriptor.Descriptor(
  name='BitSetProto',
  full_name='rockset.BitSetProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='blocks', full_name='rockset.BitSetProto.blocks', index=0,
      number=1, type=7, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4151,
  serialized_end=4180,
)

_DATETIMEPROTO.fields_by_name['date'].message_type = _DATEPROTO
_DATETIMEPROTO.fields_by_name['time'].message_type = _TIMEPROTO
_GEOGRAPHYLINESTRINGPROTO.fields_by_name['points'].message_type = _GEOGRAPHYPOINTPROTO
_GEOGRAPHYPOLYGONPROTO.fields_by_name['loops'].message_type = _GEOGRAPHYLINESTRINGPROTO
_GEOGRAPHYPROTO.fields_by_name['point'].message_type = _GEOGRAPHYPOINTPROTO
_GEOGRAPHYPROTO.fields_by_name['line_string'].message_type = _GEOGRAPHYLINESTRINGPROTO
_GEOGRAPHYPROTO.fields_by_name['polygon'].message_type = _GEOGRAPHYPOLYGONPROTO
_GEOGRAPHYPROTO.fields_by_name['range_endpoint'].message_type = _GEOGRAPHYRANGEENDPOINTPROTO
_GEOGRAPHYPROTO.oneofs_by_name['geography_union'].fields.append(
  _GEOGRAPHYPROTO.fields_by_name['point'])
_GEOGRAPHYPROTO.fields_by_name['point'].containing_oneof = _GEOGRAPHYPROTO.oneofs_by_name['geography_union']
_GEOGRAPHYPROTO.oneofs_by_name['geography_union'].fields.append(
  _GEOGRAPHYPROTO.fields_by_name['line_string'])
_GEOGRAPHYPROTO.fields_by_name['line_string'].containing_oneof = _GEOGRAPHYPROTO.oneofs_by_name['geography_union']
_GEOGRAPHYPROTO.oneofs_by_name['geography_union'].fields.append(
  _GEOGRAPHYPROTO.fields_by_name['polygon'])
_GEOGRAPHYPROTO.fields_by_name['polygon'].containing_oneof = _GEOGRAPHYPROTO.oneofs_by_name['geography_union']
_GEOGRAPHYPROTO.oneofs_by_name['geography_union'].fields.append(
  _GEOGRAPHYPROTO.fields_by_name['range_endpoint'])
_GEOGRAPHYPROTO.fields_by_name['range_endpoint'].containing_oneof = _GEOGRAPHYPROTO.oneofs_by_name['geography_union']
_VALUE.fields_by_name['object_value'].message_type = _OBJECTVALUE
_VALUE.fields_by_name['array_value'].message_type = _ARRAYVALUE
_VALUE.fields_by_name['custom_value'].message_type = _CUSTOMVALUE
_VALUE.fields_by_name['locator_value'].message_type = rockset_dot_document__locator__pb2._DOCUMENTLOCATORPROTO
_VALUE.fields_by_name['datetime_value'].message_type = _DATETIMEPROTO
_VALUE.fields_by_name['date_value'].message_type = _DATEPROTO
_VALUE.fields_by_name['time_value'].message_type = _TIMEPROTO
_VALUE.fields_by_name['geography_value'].message_type = _GEOGRAPHYPROTO
_VALUE.fields_by_name['int_array_value'].message_type = _INTARRAYVALUE
_VALUE.fields_by_name['float_array_value'].message_type = _FLOATARRAYVALUE
_VALUE.fields_by_name['bool_array_value'].message_type = _BOOLARRAYVALUE
_VALUE.fields_by_name['string_array_value'].message_type = _STRINGARRAYVALUE
_VALUE.fields_by_name['locator_array_value'].message_type = _LOCATORARRAYVALUE
_VALUE.fields_by_name['timestamp_array_value'].message_type = _TIMESTAMPARRAYVALUE
_VALUE.fields_by_name['date_time_array_value'].message_type = _DATETIMEARRAYVALUE
_VALUE.fields_by_name['date_array_value'].message_type = _DATEARRAYVALUE
_VALUE.fields_by_name['time_array_value'].message_type = _TIMEARRAYVALUE
_VALUE.fields_by_name['month_interval_array_value'].message_type = _MONTHINTERVALARRAYVALUE
_VALUE.fields_by_name['microsecond_interval_array_value'].message_type = _MICROSECONDINTERVALARRAYVALUE
_VALUE.fields_by_name['int128_value'].message_type = _INT128PROTO
_VALUE.fields_by_name['int128_array_value'].message_type = _INT128ARRAYVALUE
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['int_value'])
_VALUE.fields_by_name['int_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['float_value'])
_VALUE.fields_by_name['float_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['bool_value'])
_VALUE.fields_by_name['bool_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['string_value'])
_VALUE.fields_by_name['string_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['bytes_value'])
_VALUE.fields_by_name['bytes_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['object_value'])
_VALUE.fields_by_name['object_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['array_value'])
_VALUE.fields_by_name['array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['custom_value'])
_VALUE.fields_by_name['custom_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['null_value'])
_VALUE.fields_by_name['null_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['locator_value'])
_VALUE.fields_by_name['locator_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['timestamp_value'])
_VALUE.fields_by_name['timestamp_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['datetime_value'])
_VALUE.fields_by_name['datetime_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['date_value'])
_VALUE.fields_by_name['date_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['time_value'])
_VALUE.fields_by_name['time_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['month_interval_value'])
_VALUE.fields_by_name['month_interval_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['microsecond_interval_value'])
_VALUE.fields_by_name['microsecond_interval_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['unknown_value'])
_VALUE.fields_by_name['unknown_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['geography_value'])
_VALUE.fields_by_name['geography_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['int_array_value'])
_VALUE.fields_by_name['int_array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['float_array_value'])
_VALUE.fields_by_name['float_array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['bool_array_value'])
_VALUE.fields_by_name['bool_array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['string_array_value'])
_VALUE.fields_by_name['string_array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['locator_array_value'])
_VALUE.fields_by_name['locator_array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['timestamp_array_value'])
_VALUE.fields_by_name['timestamp_array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['date_time_array_value'])
_VALUE.fields_by_name['date_time_array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['date_array_value'])
_VALUE.fields_by_name['date_array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['time_array_value'])
_VALUE.fields_by_name['time_array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['month_interval_array_value'])
_VALUE.fields_by_name['month_interval_array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['microsecond_interval_array_value'])
_VALUE.fields_by_name['microsecond_interval_array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['int128_value'])
_VALUE.fields_by_name['int128_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_VALUE.oneofs_by_name['value_union'].fields.append(
  _VALUE.fields_by_name['int128_array_value'])
_VALUE.fields_by_name['int128_array_value'].containing_oneof = _VALUE.oneofs_by_name['value_union']
_FIELD.fields_by_name['value'].message_type = _VALUE
_OBJECTVALUE.fields_by_name['fields'].message_type = _FIELD
_ARRAYVALUE.fields_by_name['value'].message_type = _VALUE
_INTARRAYVALUE.fields_by_name['nulls'].message_type = _NULLSVALUE
_FLOATARRAYVALUE.fields_by_name['nulls'].message_type = _NULLSVALUE
_BOOLARRAYVALUE.fields_by_name['nulls'].message_type = _NULLSVALUE
_STRINGARRAYVALUE.fields_by_name['nulls'].message_type = _NULLSVALUE
_STRINGARRAYVALUE.fields_by_name['dictionary'].message_type = _STRINGARRAYVALUEDICTIONARY
_LOCATORARRAYVALUE.fields_by_name['value'].message_type = rockset_dot_document__locator__pb2._DOCUMENTLOCATORPROTO
_LOCATORARRAYVALUE.fields_by_name['nulls'].message_type = _NULLSVALUE
_TIMESTAMPARRAYVALUE.fields_by_name['nulls'].message_type = _NULLSVALUE
_DATETIMEARRAYVALUE.fields_by_name['value'].message_type = _DATETIMEPROTO
_DATETIMEARRAYVALUE.fields_by_name['nulls'].message_type = _NULLSVALUE
_DATEARRAYVALUE.fields_by_name['value'].message_type = _DATEPROTO
_DATEARRAYVALUE.fields_by_name['nulls'].message_type = _NULLSVALUE
_TIMEARRAYVALUE.fields_by_name['value'].message_type = _TIMEPROTO
_TIMEARRAYVALUE.fields_by_name['nulls'].message_type = _NULLSVALUE
_MONTHINTERVALARRAYVALUE.fields_by_name['nulls'].message_type = _NULLSVALUE
_MICROSECONDINTERVALARRAYVALUE.fields_by_name['nulls'].message_type = _NULLSVALUE
_INT128ARRAYVALUE.fields_by_name['value'].message_type = _INT128PROTO
_INT128ARRAYVALUE.fields_by_name['nulls'].message_type = _NULLSVALUE
_TYPE.fields_by_name['type'].enum_type = _TYPE_SCALARTYPE
_TYPE.fields_by_name['object_type'].message_type = _OBJECTTYPE
_TYPE.fields_by_name['array_type'].message_type = _ARRAYTYPE
_TYPE.fields_by_name['custom_type'].message_type = _CUSTOMTYPE
_TYPE.fields_by_name['default_value'].message_type = _VALUE
_TYPE.fields_by_name['source_field'].message_type = _TYPE
_TYPE_SCALARTYPE.containing_type = _TYPE
_TYPE.oneofs_by_name['type_union'].fields.append(
  _TYPE.fields_by_name['type'])
_TYPE.fields_by_name['type'].containing_oneof = _TYPE.oneofs_by_name['type_union']
_TYPE.oneofs_by_name['type_union'].fields.append(
  _TYPE.fields_by_name['object_type'])
_TYPE.fields_by_name['object_type'].containing_oneof = _TYPE.oneofs_by_name['type_union']
_TYPE.oneofs_by_name['type_union'].fields.append(
  _TYPE.fields_by_name['array_type'])
_TYPE.fields_by_name['array_type'].containing_oneof = _TYPE.oneofs_by_name['type_union']
_TYPE.oneofs_by_name['type_union'].fields.append(
  _TYPE.fields_by_name['custom_type'])
_TYPE.fields_by_name['custom_type'].containing_oneof = _TYPE.oneofs_by_name['type_union']
_KEYTYPE.fields_by_name['type'].message_type = _TYPE
_OBJECTTYPE.fields_by_name['kt'].message_type = _KEYTYPE
_ARRAYTYPE.fields_by_name['type'].message_type = _TYPE
DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
DESCRIPTOR.message_types_by_name['DateProto'] = _DATEPROTO
DESCRIPTOR.message_types_by_name['TimeProto'] = _TIMEPROTO
DESCRIPTOR.message_types_by_name['DateTimeProto'] = _DATETIMEPROTO
DESCRIPTOR.message_types_by_name['GeographyPointProto'] = _GEOGRAPHYPOINTPROTO
DESCRIPTOR.message_types_by_name['GeographyLineStringProto'] = _GEOGRAPHYLINESTRINGPROTO
DESCRIPTOR.message_types_by_name['GeographyPolygonProto'] = _GEOGRAPHYPOLYGONPROTO
DESCRIPTOR.message_types_by_name['GeographyRangeEndpointProto'] = _GEOGRAPHYRANGEENDPOINTPROTO
DESCRIPTOR.message_types_by_name['GeographyProto'] = _GEOGRAPHYPROTO
DESCRIPTOR.message_types_by_name['Int128Proto'] = _INT128PROTO
DESCRIPTOR.message_types_by_name['Value'] = _VALUE
DESCRIPTOR.message_types_by_name['CustomValue'] = _CUSTOMVALUE
DESCRIPTOR.message_types_by_name['Field'] = _FIELD
DESCRIPTOR.message_types_by_name['ObjectValue'] = _OBJECTVALUE
DESCRIPTOR.message_types_by_name['ArrayValue'] = _ARRAYVALUE
DESCRIPTOR.message_types_by_name['NullsValue'] = _NULLSVALUE
DESCRIPTOR.message_types_by_name['IntArrayValue'] = _INTARRAYVALUE
DESCRIPTOR.message_types_by_name['FloatArrayValue'] = _FLOATARRAYVALUE
DESCRIPTOR.message_types_by_name['BoolArrayValue'] = _BOOLARRAYVALUE
DESCRIPTOR.message_types_by_name['StringArrayValueDictionary'] = _STRINGARRAYVALUEDICTIONARY
DESCRIPTOR.message_types_by_name['StringArrayValue'] = _STRINGARRAYVALUE
DESCRIPTOR.message_types_by_name['LocatorArrayValue'] = _LOCATORARRAYVALUE
DESCRIPTOR.message_types_by_name['TimestampArrayValue'] = _TIMESTAMPARRAYVALUE
DESCRIPTOR.message_types_by_name['DateTimeArrayValue'] = _DATETIMEARRAYVALUE
DESCRIPTOR.message_types_by_name['DateArrayValue'] = _DATEARRAYVALUE
DESCRIPTOR.message_types_by_name['TimeArrayValue'] = _TIMEARRAYVALUE
DESCRIPTOR.message_types_by_name['MonthIntervalArrayValue'] = _MONTHINTERVALARRAYVALUE
DESCRIPTOR.message_types_by_name['MicrosecondIntervalArrayValue'] = _MICROSECONDINTERVALARRAYVALUE
DESCRIPTOR.message_types_by_name['Int128ArrayValue'] = _INT128ARRAYVALUE
DESCRIPTOR.message_types_by_name['Type'] = _TYPE
DESCRIPTOR.message_types_by_name['KeyType'] = _KEYTYPE
DESCRIPTOR.message_types_by_name['ObjectType'] = _OBJECTTYPE
DESCRIPTOR.message_types_by_name['ArrayType'] = _ARRAYTYPE
DESCRIPTOR.message_types_by_name['CustomType'] = _CUSTOMTYPE
DESCRIPTOR.message_types_by_name['BitSetProto'] = _BITSETPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
  'DESCRIPTOR' : _EMPTY,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Empty)
  })
_sym_db.RegisterMessage(Empty)

DateProto = _reflection.GeneratedProtocolMessageType('DateProto', (_message.Message,), {
  'DESCRIPTOR' : _DATEPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.DateProto)
  })
_sym_db.RegisterMessage(DateProto)

TimeProto = _reflection.GeneratedProtocolMessageType('TimeProto', (_message.Message,), {
  'DESCRIPTOR' : _TIMEPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.TimeProto)
  })
_sym_db.RegisterMessage(TimeProto)

DateTimeProto = _reflection.GeneratedProtocolMessageType('DateTimeProto', (_message.Message,), {
  'DESCRIPTOR' : _DATETIMEPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.DateTimeProto)
  })
_sym_db.RegisterMessage(DateTimeProto)

GeographyPointProto = _reflection.GeneratedProtocolMessageType('GeographyPointProto', (_message.Message,), {
  'DESCRIPTOR' : _GEOGRAPHYPOINTPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.GeographyPointProto)
  })
_sym_db.RegisterMessage(GeographyPointProto)

GeographyLineStringProto = _reflection.GeneratedProtocolMessageType('GeographyLineStringProto', (_message.Message,), {
  'DESCRIPTOR' : _GEOGRAPHYLINESTRINGPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.GeographyLineStringProto)
  })
_sym_db.RegisterMessage(GeographyLineStringProto)

GeographyPolygonProto = _reflection.GeneratedProtocolMessageType('GeographyPolygonProto', (_message.Message,), {
  'DESCRIPTOR' : _GEOGRAPHYPOLYGONPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.GeographyPolygonProto)
  })
_sym_db.RegisterMessage(GeographyPolygonProto)

GeographyRangeEndpointProto = _reflection.GeneratedProtocolMessageType('GeographyRangeEndpointProto', (_message.Message,), {
  'DESCRIPTOR' : _GEOGRAPHYRANGEENDPOINTPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.GeographyRangeEndpointProto)
  })
_sym_db.RegisterMessage(GeographyRangeEndpointProto)

GeographyProto = _reflection.GeneratedProtocolMessageType('GeographyProto', (_message.Message,), {
  'DESCRIPTOR' : _GEOGRAPHYPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.GeographyProto)
  })
_sym_db.RegisterMessage(GeographyProto)

Int128Proto = _reflection.GeneratedProtocolMessageType('Int128Proto', (_message.Message,), {
  'DESCRIPTOR' : _INT128PROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Int128Proto)
  })
_sym_db.RegisterMessage(Int128Proto)

Value = _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), {
  'DESCRIPTOR' : _VALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Value)
  })
_sym_db.RegisterMessage(Value)

CustomValue = _reflection.GeneratedProtocolMessageType('CustomValue', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.CustomValue)
  })
_sym_db.RegisterMessage(CustomValue)

Field = _reflection.GeneratedProtocolMessageType('Field', (_message.Message,), {
  'DESCRIPTOR' : _FIELD,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Field)
  })
_sym_db.RegisterMessage(Field)

ObjectValue = _reflection.GeneratedProtocolMessageType('ObjectValue', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.ObjectValue)
  })
_sym_db.RegisterMessage(ObjectValue)

ArrayValue = _reflection.GeneratedProtocolMessageType('ArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _ARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.ArrayValue)
  })
_sym_db.RegisterMessage(ArrayValue)

NullsValue = _reflection.GeneratedProtocolMessageType('NullsValue', (_message.Message,), {
  'DESCRIPTOR' : _NULLSVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.NullsValue)
  })
_sym_db.RegisterMessage(NullsValue)

IntArrayValue = _reflection.GeneratedProtocolMessageType('IntArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _INTARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.IntArrayValue)
  })
_sym_db.RegisterMessage(IntArrayValue)

FloatArrayValue = _reflection.GeneratedProtocolMessageType('FloatArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _FLOATARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.FloatArrayValue)
  })
_sym_db.RegisterMessage(FloatArrayValue)

BoolArrayValue = _reflection.GeneratedProtocolMessageType('BoolArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _BOOLARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.BoolArrayValue)
  })
_sym_db.RegisterMessage(BoolArrayValue)

StringArrayValueDictionary = _reflection.GeneratedProtocolMessageType('StringArrayValueDictionary', (_message.Message,), {
  'DESCRIPTOR' : _STRINGARRAYVALUEDICTIONARY,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.StringArrayValueDictionary)
  })
_sym_db.RegisterMessage(StringArrayValueDictionary)

StringArrayValue = _reflection.GeneratedProtocolMessageType('StringArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _STRINGARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.StringArrayValue)
  })
_sym_db.RegisterMessage(StringArrayValue)

LocatorArrayValue = _reflection.GeneratedProtocolMessageType('LocatorArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _LOCATORARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.LocatorArrayValue)
  })
_sym_db.RegisterMessage(LocatorArrayValue)

TimestampArrayValue = _reflection.GeneratedProtocolMessageType('TimestampArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _TIMESTAMPARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.TimestampArrayValue)
  })
_sym_db.RegisterMessage(TimestampArrayValue)

DateTimeArrayValue = _reflection.GeneratedProtocolMessageType('DateTimeArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _DATETIMEARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.DateTimeArrayValue)
  })
_sym_db.RegisterMessage(DateTimeArrayValue)

DateArrayValue = _reflection.GeneratedProtocolMessageType('DateArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _DATEARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.DateArrayValue)
  })
_sym_db.RegisterMessage(DateArrayValue)

TimeArrayValue = _reflection.GeneratedProtocolMessageType('TimeArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _TIMEARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.TimeArrayValue)
  })
_sym_db.RegisterMessage(TimeArrayValue)

MonthIntervalArrayValue = _reflection.GeneratedProtocolMessageType('MonthIntervalArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _MONTHINTERVALARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.MonthIntervalArrayValue)
  })
_sym_db.RegisterMessage(MonthIntervalArrayValue)

MicrosecondIntervalArrayValue = _reflection.GeneratedProtocolMessageType('MicrosecondIntervalArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _MICROSECONDINTERVALARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.MicrosecondIntervalArrayValue)
  })
_sym_db.RegisterMessage(MicrosecondIntervalArrayValue)

Int128ArrayValue = _reflection.GeneratedProtocolMessageType('Int128ArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _INT128ARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Int128ArrayValue)
  })
_sym_db.RegisterMessage(Int128ArrayValue)

Type = _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {
  'DESCRIPTOR' : _TYPE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Type)
  })
_sym_db.RegisterMessage(Type)

KeyType = _reflection.GeneratedProtocolMessageType('KeyType', (_message.Message,), {
  'DESCRIPTOR' : _KEYTYPE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.KeyType)
  })
_sym_db.RegisterMessage(KeyType)

ObjectType = _reflection.GeneratedProtocolMessageType('ObjectType', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTTYPE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.ObjectType)
  })
_sym_db.RegisterMessage(ObjectType)

ArrayType = _reflection.GeneratedProtocolMessageType('ArrayType', (_message.Message,), {
  'DESCRIPTOR' : _ARRAYTYPE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.ArrayType)
  })
_sym_db.RegisterMessage(ArrayType)

CustomType = _reflection.GeneratedProtocolMessageType('CustomType', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMTYPE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.CustomType)
  })
_sym_db.RegisterMessage(CustomType)

BitSetProto = _reflection.GeneratedProtocolMessageType('BitSetProto', (_message.Message,), {
  'DESCRIPTOR' : _BITSETPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.BitSetProto)
  })
_sym_db.RegisterMessage(BitSetProto)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
